Package: qwraps2
Title: Quick Wraps 2
Version: 0.6.3
Authors@R: c(
    person(given = "Peter", family = "DeWitt",  email = "dewittpe@gmail.com",          role = c("aut", "cre"), comment = c(ORCID = "0000-0002-6391-0795")),
    person(given = "Tell",  family = "Bennett", email = "tell.bennett@cuanschutz.edu", role = c("ctb"),        comment = c(ORCID = "0000-0003-1483-4236"))
    )
Description: A collection of (wrapper) functions the creator found useful
    for quickly placing data summaries and formatted regression results into
    '.Rnw' or '.Rmd' files. Functions for generating commonly used graphics,
    such as receiver operating curves or Bland-Altman plots, are also provided
    by 'qwraps2'.  'qwraps2' is an updated version of a package 'qwraps'. The
    original version 'qwraps' was never submitted to CRAN but can be found at
    <https://github.com/dewittpe/qwraps/>. The implementation and limited scope
    of the functions within 'qwraps2' <https://github.com/dewittpe/qwraps2/> is
    fundamentally different from 'qwraps'.
Depends: R (>= 3.5.0)
License: GPL (>= 3)
Encoding: UTF-8
URL: https://github.com/dewittpe/qwraps2/,
        https://www.peteredewitt.com/qwraps2/
BugReports: https://github.com/dewittpe/qwraps2/issues
Language: en-us
LazyData: true
Imports: ggplot2, knitr, Rcpp (>= 0.12.11), utils, xfun
Suggests: dplyr (>= 1.0.0), survival, covr, glmnet, rmarkdown
LinkingTo: Rcpp (>= 0.12.11), RcppArmadillo
VignetteBuilder: knitr, rmarkdown
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-06-17 19:53:21 UTC; dewittp
Author: Peter DeWitt [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6391-0795>),
  Tell Bennett [ctb] (ORCID: <https://orcid.org/0000-0003-1483-4236>)
Maintainer: Peter DeWitt <dewittpe@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-18 05:10:07 UTC
