# Generated by roxygen2: do not edit by hand

S3method(cbind,qwraps2_qable)
S3method(confusion_matrix,default)
S3method(confusion_matrix,formula)
S3method(confusion_matrix,glm)
S3method(extract_fpvalue,lm)
S3method(extract_fstat,lm)
S3method(frmtci,data.frame)
S3method(frmtci,default)
S3method(frmtci,matrix)
S3method(frmtci,qwraps2_mean_ci)
S3method(ggplot2_extract_legend,ggplot)
S3method(print,qwraps2_confusion_matrix)
S3method(print,qwraps2_file_check)
S3method(print,qwraps2_ggplot2_extracted_legend)
S3method(print,qwraps2_mean_ci)
S3method(print,qwraps2_pkg_check)
S3method(print,qwraps2_qable)
S3method(print,qwraps2_set_diff)
S3method(print,qwraps2_summary_table)
S3method(qable,data.frame)
S3method(qable,matrix)
S3method(qacf,data.frame)
S3method(qacf,default)
S3method(qblandaltman,data.frame)
S3method(qblandaltman,default)
S3method(qkmplot,default)
S3method(qkmplot,qkmplot_data)
S3method(qkmplot,survfit)
S3method(qkmplot_build_data_frame,survfit)
S3method(qprc,default)
S3method(qprc,glm)
S3method(qprc,qwraps2_confusion_matrix)
S3method(qrmst,qkmplot_data)
S3method(qrmst,survfit)
S3method(qroc,default)
S3method(qroc,glm)
S3method(qroc,qwraps2_confusion_matrix)
S3method(qroc_build_data_frame,default)
S3method(qroc_build_data_frame,glm)
S3method(qsummary,data.frame)
S3method(qsummary,grouped_df)
S3method(rbind,qwraps2_qable)
S3method(summary_table,data.frame)
S3method(summary_table,grouped_df)
export("%s%")
export(CRANpkg)
export(GitHubpkg)
export(Githubpkg)
export(Gitlabpkg)
export(Rpkg)
export(StatStepribbon)
export(backtick)
export(confusion_matrix)
export(extract_fpvalue)
export(extract_fstat)
export(file_check)
export(frmt)
export(frmtci)
export(frmtp)
export(ggplot2_extract_legend)
export(gmean)
export(gmean_sd)
export(gsd)
export(gvar)
export(invlogit)
export(lazyload_cache_dir)
export(lazyload_cache_labels)
export(ll)
export(logit)
export(mean_ci)
export(mean_sd)
export(mean_se)
export(median_iqr)
export(n_perc)
export(n_perc0)
export(perc_n)
export(pkg_check)
export(qable)
export(qacf)
export(qblandaltman)
export(qblandaltman_build_data_frame)
export(qkmplot)
export(qkmplot_build_data_frame)
export(qkmplot_bulid_data_frame)
export(qprc)
export(qprc_build_data_frame)
export(qrmst)
export(qroc)
export(qroc_build_data_frame)
export(qsummary)
export(set_diff)
export(spin_comments)
export(stat_stepribbon)
export(summary_table)
export(traprule)
importFrom(Rcpp,sourceCpp)
useDynLib(qwraps2)
