#' # Spinner 1
#'
#' This file is a simple R script used to show the use of the spin comment
#' checking function.
# /* opening C-style comment
2 + 2
# end of the first comment */
#'
#'
exp(- 1i * pi)

#'
#'
#' More text and then an clossing comment, there is a missing openning.
# */

#'
#' What about openning without closing?
#'
# /*

# /* opened
sum(1:10)
# closed */
